@@ -118,7 +118,7 @@ def install_environment(
 
 
 def run_hook(
-        hook: 'Hook',
+        hook: Hook,
         file_args: Sequence[str],
         color: bool,
 ) -> Tuple[int, bytes]:  # pragma: windows no cover
